#include <R.h>
#include <Rinternals.h>

#ifndef _SUBSETISM_H_
#define _SUBSETISM_H_

SEXP subsetInfSparseMatrix(SEXP whichRows, SEXP whichCols, SEXP x);

#endif
